#
# spec file for package perl-Prima
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Prima
Name:           perl-Prima
Version:        1.75000
Release:        1.2
%define cpan_version 1.75
#Upstream: SUSE-Public-Domain
License:        AGPL-3.0-only AND BSD-2-Clause
Summary:        Perl graphic toolkit
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/K/KA/KARASIK/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Prima) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  giflib-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  xkeyboard-config
BuildRequires:  xorg-x11
BuildRequires:  xorg-x11-Xvfb
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
%define         X_display         ":98"
Requires:       xorg-x11
# MANUAL END

%description
Prima is a classic 2D GUI toolkit that works under Windows and X11
environments. The toolkit features a rich widget library, extensive 2D
graphic support, PDF generation, modern Unicode text input and output, and
supports a wide set of image formats. Additionally, the RAD-style Visual
Builder and POD viewer are included. The toolkit can interoperate with
other popular event loop libraries.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
# MANUAL BEGIN
## oops, Prima/Config.pm must not contain BUILD_ROOT
find $RPM_BUILD_ROOT -name 'Config.pm' -print0 | xargs -0 perl -i -pe "s{\\Q$RPM_BUILD_ROOT}"'{}g'
###
### should these go to a perl-Prima-devel ?
find $RPM_BUILD_ROOT/%{perl_vendorarch} -name \*.h | xargs -t rm
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%doc AGPLv3 Changes examples README.md
%license Copying LICENSE

%changelog
* Sun Dec 22 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.75
  see /usr/share/doc/packages/perl-Prima/Changes
  1.75 2024-12-21
  - FrameSet: rename .arrangement to .vertical, remove .resizeMethod
  - add Date,Time,KeySelector,FrameSet, and CheckList to VB
  - s/dragable/draggable/g
  - Grouped menu items use a distinct radio style check mark bitmap
  - Support CPAL/COLR colored fonts
  - Add the PopupButton class
* Tue Aug 20 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.74
  see /usr/share/doc/packages/perl-Prima/Changes
  1.74 2024-08-24
  - implement antialiased polygon fill in C, use it in the
    AA emulation in Prima::Drawable::Antialias instead of the old algorithm
  - all AA plotting is supported internally, Prima::Drawable::Antialias is
    not used for the emulated AA drawing
  - add kb:: definitions for the internet keyboards
  - fixes for Strawberry Perl 5.40
* Fri May 10 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.73
  see /usr/share/doc/packages/perl-Prima/Changes
  1.73 2024-05-07
  - add Prima::Image::Exif, support jpeg tags
  - better compatibility for text rendering outside paint
  - add examples/text-render.pl, inspired by hb_view
* Thu Feb  1 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.72
  see /usr/share/doc/packages/perl-Prima/Changes
  1.72 2024-01-31
  - Major rehaul of ROP constants with API compatibility break:
  - - rop(R), put_image(X,Y,I) will not use rop R but rop::Default instead
  - - rop::Blend and rop::CopyPut are no longer equal. rop::XorPut and rop::Xor
    are no longer equal; the latter is rop::XorOver now.
  - Image.text_out() works outside the paint mode by querying glyph bitmaps.
    Other text- and font- related method work too.
  - Pod parsing and rendering moved to Prima::Drawable::Pod
  - - added utils/pod2pdf that works without needing a X11 server
  - Font.underlinePosition and Font.underlineThickness are added
  - Image.has_codec added
  - Prima::Image::Loader and per-frame image loading and saving is added
  - Utils.sound is removed
* Mon Oct 30 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.71
  see /usr/share/doc/packages/perl-Prima/Changes
  1.71 2023-10-29
  - Add Prima::Image::webp filter dialog
  - Add DeviceBitmap.maskPixel
  - Add menus to file dialogs
  - Remove obsolete RadioGroup and CheckBoxGroup - use GroupBox instead
  - Proofread all documentation through Grammarly
* Tue Sep  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.70
  see /usr/share/doc/packages/perl-Prima/Changes
  1.70 2023-09-03
  - Use fading effects in widgets
  - Solidify emulated 2D transformations with images
  - - Add aperture point for Image.matrix_transform
  - Animation is using core image processing instead of DeviceBitmap
  - Path rendering is optimized for widened arcs and splines
  - Add Widget.is_surface_buffered to check if .buffered(1) was respected
  - Edit.find() changed the coordinate system used, from visual to physical
  - Core Icon.put_image(Icon) will affect the destinations 1-bit mask
  - Image.premultiply_alpha(constant) will work on palettes when bpp <= 8
  - Add Image.to_colormask
  - Add --no-xrender-matrix command line switch for x11 builds
* Thu Jun  1 2023 Tina Müller <tina.mueller@suse.com>
- Set version to 1.69000 to ensure it's bigger than the previous
  version. This distribution uses altering version lengths.
* Wed May 31 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.69
  see /usr/share/doc/packages/perl-Prima/Changes
* Thu May 11 2023 Dirk Stoecker <opensuse@dstoecker.de>
- update cpanspec.yml and recreate spec file
* Sun May  7 2023 Jan Engelhardt <jengelh@inai.de>
- Replace xorg-x11-devel by pkgconfig(...)
* Mon Feb 13 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.67001
  see /usr/share/doc/packages/perl-Prima/Changes
  1.68 2023-XX-XX
  - Process signals inside event loop
  - Add sys::GUIException, onDie, and a standard dialog for user interactions on exceptions
  - Widget.onMouseClick.dblclick::bool is .nth::int now, can report triple, quadruple etc clicks
  - Support fillPattern with tiles in the emulated antialiasing
  - Add Date and Time widgets (and their example/clock.pl)
  - Remove native Win32 support from cygwin builds
  - File.onRead supports native Win32 console stdin event
  - Support XIM input
  1.67 2022-11-27
  - Links and tooltips extended functionality:
  - - Added interactive links in Label
  - - Markup recognizes hyperlinks now with new "L<URL|text>" syntax
  - - Generic link opening is handled by new module Prima::Widget::Link
  - - Pod-embedded base64-encoded images are supported in podview and tooltips
  - Some modules were split and moved to Prima::Widget:: namespace
  - Compilation update for the latest MSVC
  - use Prima qw(MsgBox and the like) re-exports symbols to the caller level:
    message() will do now instead of Prima::MsgBox::message()
  - Added conversion helpers:
  - - Prima::Image.to_rgba()
  - - cl::to_gray_byte(), cl::to_gray_rgb(), cl::from_gray_byte()
  - ColorDialog and ColorComboBox support grayscale mode
  - Image.rotate() has new fill parameter
  - Major rewrite of plotting primitives by Drawable:
  - - lineEnd,linePattern,lineWidth,miterLimit,lineJoin are served by
    Prima::Drawable::Path now if lineWidth > 0
  - - Note: antialiased lines with width = 0 are invisible now!
  - - Prima::Drawable::Path is heavily optimized
  - - Drawable.matrix() is supported for all plotting primitives
  - - Drawable.translate() is a syntax sugar for matrix operations
  - - Drawable line ends are customizable now (see Drawable.pod, "Custom line end styles" )
  - - Regions defined by polylines and images are internally plotted
  - Drawable.render_pattern emulates fill patterns distorted via matrix transformations
  - X11:
  - - better support of window icons
  - - better support of multiple monitors
* Sun Aug 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.66
  see /usr/share/doc/packages/perl-Prima/Changes
* Thu Apr 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.65
  see /usr/share/doc/packages/perl-Prima/Changes
  1.65 2022-04-18
  - fixed 1.64 broken distro
  1.64 2022-04-09
  - Use libthai for Drawable.text_wrap
  - PS/PDF font metric calculations simplified and fixed
  - POD printing quality improved
  - Support Drawable.alpha in the PDF backend
* Sat Sep 11 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.63
  see /usr/share/doc/packages/perl-Prima/Changes
* Thu Jun 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.62
  see /usr/share/doc/packages/perl-Prima/Changes
  1.62 2021-06-16
  - Add opendir/closedir/*dir for unicode operations
  - Add Prima::Drawable::Antialias for drawing aliased graphic primitives
  - Interactive selection change in Edit and PodView does not flicker now
  - Drawable::text_wrap can operate on text together with glyph objects,
    allowing for proper wrapping of shaped text
  - Added ist::OR and ist::AND image stretch types
  - Implemented arabic kashida and interspace justifications for glyphs
  - Markup is a first class citizen with $w->text(\"B<bold>") syntax
    (note: Q was renamed to G and will be used for quoting instead).
  - Minor UI facelift - sliders, buttons, inputline, podview, etc
  - Added Prima::Drawable::Metafile
  - Recognize mouse buttons 4 and 5 on win32
  - win32: support unicode supplementary planes
* Sat Apr 24 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.61
  see /usr/share/doc/packages/perl-Prima/Changes
  1.61 2021-04-21
  - DWM API Removed (not useful on Windows 10)
  - Support regions and paths for the PS backend
  - Prima::XXXDialog classes finally moved to Prima::XXX::Dialog
  - Support unicode-aware filesystem functions
  - - Prima::Utils extended and Prima::sys::FS added
  - - Do not use libX11.XReadBitmapFileData as it is not unicode-aware
  - Add Application.stop to break from a running event loop
* Sun Nov  1 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.60
  see /usr/share/doc/packages/perl-Prima/Changes
  1.60 2020-10-31
  - Added ProgressBar with 3d look
  - Added PDF generation
  - - PrintDialog has extra "Save As PDF" target now
  - Clipboard enhancements
  - - cmClipboard added for X11 to select type of data to be pasted
  - - Image codecs return MIME as part of codec data
  - - Special formats Text and Image are documented
  - - Added Clipboard.[text/image/copy] KEEP parameter
  - Image.put_image supports new rop::ConstantColor
  - Optimizations for cache misses in Drawable.text_wrap
  - Fixes for unicode handling in FileDialog and Utils::get_dir
  - Fixes for XRandr extension
  - Fixes for scrolling with synthetic transparency in win32
* Thu May 28 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.59
  see /usr/share/doc/packages/perl-Prima/Changes
  1.59 2020-05-27
  - Added support for unicode bidirectional algorithm and text shaping:
  - - All standard widgets are moved to new shaped text implementation:
    formerly char-based position properties, such as firstChar and selection,
    are now cluster-based.
  - - Unicode bidirectional algorithms uses fribidi on all platforms
  - - Text shaping uses harfbuzz on unix
  - - Text::Bidi is no loger used
  - - Text input direction is deduced from new Application.language
  - Switch PostScript backend to generate embedded Type1 fonts only
  - - Remove bitmap font generation and remove support for native PS fonts
  - - Remove support for encodings, leave only Unicode
  - Move Prima::*Dialog.pm files into Prima::Dialog::* namespace.
  - - The old packages will be alive for a while, but will print a deprecation message
* Mon Mar 16 2020 <timueller+perl@suse.de>
- updated to 1.58
  see /usr/share/doc/packages/perl-Prima/Changes
* Tue Nov 19 2019 <timueller+perl@suse.de>
- updated to 1.57
  see /usr/share/doc/packages/perl-Prima/Changes
  1.57 2017-11-17
  - Add photoshop image operators (rop::Add, rop::Multiply, rop::SoftLight etc)
  - Support animated PNG files
  - Add Image.flood_fill
* Wed Aug 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.56
  see /usr/share/doc/packages/perl-Prima/Changes
  1.56 2019-08-19
  - Rename and expand Drawable.fillWinding to .fillMode
  - Add Drawable.render_glyph and glyph outline functions
  - Add Drawable.miterLimit
  - Drawable.render_spline produces 8-connected shapes instead of 4-connected
  - Image can stroke and fill shapes outside begin_paint now
  - Image drawing outside begin_paint supports regions,translations,patterns,and rop2
  - Regions can keep a non-OS-specific data copy, when needed by Image drawing
  - Region.new(box) supports polybox structure from .get_boxes()
  - Add sv::FixedPointerSize do deal with pointer size limits
  - Better support for touchpad scrolling
* Sat Mar 30 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.55
  see /usr/share/doc/packages/perl-Prima/Changes
  1.55 2019-03-25
  - Add WebP images support
* Tue Mar 12 2019 Lars Vogdt <lars@linux-schulserver.de>
- the software is dual-licensed and includes:
  The FreeBSD License and the GNU Affero General Public License
  => adjust the License string in the package
* Sun Feb  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.54
  see /usr/share/doc/packages/perl-Prima/Changes
  1.54 2019-02-09
  - Support screen grabbing on Mac and Gnome/Wayland
* Fri Nov  9 2018 Stephan Kulow <coolo@suse.com>
- remove upstreamed gcc-warnings.patch and Prima-GenericEvent.patch
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.53
  see /usr/share/doc/packages/perl-Prima/Changes
  1.53 2018-10-10
  - Image downsampling made consistent; added ict::Posterization;
  - Added images to documentations
  - Support gtk3 (but prefer gtk2)
  1.52 2017-06-28
  - Better support for multi-threading
  - Better support of MacOS/XQuartz
  - Aesthetic fixes for scrollbars, spin edits, and sliders
  - Fixes for paths; path demo with PS interpreter
  - Add Widget.clipChildren, Drawable.fillPatternOffset, Timer.toggle
  - Coredump fix for Data::Dumper::GUI usage pattern
  - Support colored cursors on X11
  1.51 2017-03-28
  - Add graphic paths support
  - Add spinner widgets by Maximilian Lika
  - Use Region objects for shape and clipping
  1.50 2017-01-03
  - Renamed utils after debian standard
  - Support high-dpi monitors and uiScaling, also with smooth bitmap scaling
  - Image.data/Icon.mask made faster by returning a read-only scalar
  - Support multiple monitors for win32
  - Adapt event loop for AnyEvent integration ( add onIdle and yield(1) )
  1.49 2016-09-27
  - Fixes for new development bugs in 1.48
  1.48 2016-08-21
  - Support dynamic font loading
  - Added support for invividual horizontal font glyph metrics
  - Added afm2prima script to convert .afm PostScript font headers to Prima format
  - Add Markup (rich text) widget support, originally implemented by Teo Sankaro
  - Add KeySelector integration with menu shortcuts
  - Add alpha layering and blending with native win32 and XRender support:
  - - New Drawable call .alpha()
  - - New Icon.maskType property containing either im::bpp1 or im::bpp8; the latter represents ARGB image
  - - Widgets and Windows can request per-pixel alpha transparency with new .layered property
  - - DeviceBitmap.monochrome property changed to .type(Bitmap/Pixmap/Layered)
  - - put_image and stretch_image support new rops rop::SrcCopy and rop::SrcOver with ARGB images and surfaces
  - - put_image and stretch_image support new rop::AlphaCopy with grayscale images to address alpha channel only
  - - Image bit operations support 12 Porter-Duff rops and alpha pre-multiplication on ARGB images
    and RGB images with constant alpha value
  - - PNG codec supports ARGB icons
* Sun Jun 12 2016 coolo@suse.com
- updated to 1.47
  see /usr/share/doc/packages/perl-Prima/Changes
  1.47 2016-06-03
  - Add OpenMP support for image scaling and conversion
  - Add custom image scaling algorithms
  - Support JPEG mirror/rotation tags
  - Implement image loading progress display for directions other than top-down (for jpeg and bmp)
* Mon Mar 21 2016 coolo@suse.com
- updated to 1.46
  see /usr/share/doc/packages/perl-Prima/Changes
  1.46 2016-03-16
  - Use pkg_config, when available
  - Require perl version 5.10
  - Add prelighting and gradients to widgets
  1.45 2015-11-05
  - Add Image .clone,.bar,.mirror,.rotate
  - Support bidirectional texts with Text::Bidi
* Sun Sep 20 2015 coolo@suse.com
- updated to 1.44
  see /usr/share/doc/packages/perl-Prima/Changes
  1.44 2015-08-04
  - Rewrite rubberband
  - Work on portable perls
  - Better support of graphic libs where several versions are available
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.43
  see /usr/share/doc/packages/perl-Prima/Changes
  1.43 2015-04-10
  - Rewrite font test and polish rough ends in xft font handling
  - Copy images to clipboard so that GTK recognizes them
  1.42 2015-03-11
  - Tests became TAP compliant and using Prima::Test
  - Jpeg exif orientation support added
  - Scrollbar overriding properties added for scroller widgets
- remove heavily outdated docs and VB-decent.diff
* Thu Jan 29 2015 dimstar@opensuse.org
- Update to version 1.41:
  + Add ImageViewer.autoZoom.
  + Fixes to Notebook  .
- Changes from version 1.40:
  + Remove Win9X support.
  + Cygwin default build is for X11.
  + Compile with giflib 5.1.
  + Add Drawable::Subcanvas.
  + Add ImageViewer.stretch.
  + PS font and eps fixes.
  + win32.gp cliprect fix.
- Changes from version 1.39:
  + Prepare for perl 5.20.
- Changes from version 1.38:
  + X11: add multimonitor support.
  + special char @ means auto-toggle in menu items.
* Thu Sep 12 2013 pgajdos@suse.com
- updated to 1.37
  Support libgif5. Podview fixes.
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.36
  Remove OS/2 support. Add binary compatibility checks.
  Fixes in unicode, files, documentation, installed POD paths.
* Thu Jul 19 2012 coolo@suse.com
- the license is actually BSD-2-Clause, as confirmed by the author,
  next version will have it fixed in the documentation (bnc#688800)
  (https://github.com/dk/Prima/commit/43a3fb04d9915f7f3c3cd71feb5ff247eccd04df)
* Sat Jun  2 2012 frank.lichtenheld@sophos.com
- Update to 1.34
  * 1.34: Unicode fixes, ready for 5.16
  * 1.33: Image codecs: remove prigraph, add XBM, and enhance TIFF support
  Add RubberBand.pm
- Clean up spec file, removing cruft
- Run X11 based tests with Xvfb
* Sat Nov 19 2011 coolo@suse.com
- update to 1.32
    Support image/mime clipboard formats under GTK.
    Better libiconv support.
* Wed May 18 2011 coolo@opensuse.org
- updated to 1.30
  * builds with 5.14
* Fri Apr  1 2011 coolo@novell.com
- update to 1.29
  Support for 16-bit BMP files. Fixes for modern Xorg, macos,
  and strawberry.
  Optionally support truncated image files.
  Fixes in documentation, Sliders, and key event handling.
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Tue Feb 16 2010 coolo@novell.com
- update to 1.28 (very little changelog details):
  * Support JPEG comments and metadata. Save multiframe images.
  * Abandond prigraph, adopt libjpeg/libpng/etc cohort instead.
    Develop gif animation features.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Nov 28 2008 ro@suse.de
- rename GenericEvent (X.h global namespace pollution)
* Tue Apr  8 2008 jw@suse.de
- update to Prima-1.24. The upstream HISTORY file only says this:
  1.24  Better support for mingw and cygwin. New features in VB.
  1.23  Images can load and save to streams. Image loading process can be watched.
  1.22  Use GTK file dialogs if compiled with GTK2. Better use of mouse wheel for
    Calendar, ColorDialog, ComboBox, Notebooks, Scrollbar, and Sliders widgets.
- Added a patch from Dmitry to survive all self-tests on x86_64
* Mon Aug  6 2007 jw@suse.de
- update tp Prima-1.22
  Use GTK file dialogs if compiled with GTK2. Better use of mouse wheel for
  Calendar, ColorDialog, ComboBox, Notebooks, Scrollbar, and Sliders widgets.
* Fri Jun  1 2007 jw@suse.de
- make rpmlint happy.
  No devel package with C-headers for a perl package today.
* Fri Nov 17 2006 jw@suse.de
- update to Prima-1.21
  - no new features. Plain bugfix release.
* Wed Jul 26 2006 jw@suse.de
- happy-gcc.diff added, to fix uninitialized variables in code
  generated by gencls.pl
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 jw@suse.de
- Update to Prima-1.20
* Wed Oct 19 2005 jw@suse.de
- Update to Prima-1.19
  Add Lists::vertical. Implement scrollable groups and notebooks.
  Make file and font dialogs resizeable.
* Tue Apr 26 2005 jw@suse.de
- okay sweety-6 did not like it.
  more Archs have lib64, thanks Marcus.
* Tue Apr 26 2005 jw@suse.de
- fixed warning: File listed twice
- added /usr/X11R6/lib64 for x86_64
- moved man pages out of perl_vendorarch
* Mon Apr 25 2005 jw@suse.de
- initial version: Prima-1.18
